==> vgkprogaming-0.4.2.tar.gz: lib/widget/vgk-about-us-widget/vgk-about-us-widget.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkAboutUsWidget extends StatelessWidget {
  final AnimationController animationController;
  final Animation animation;
  final String description;
  const VgkAboutUsWidget({
    Key key,
    this.animationController,
    this.animation,
    this.description,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Padding(
              padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
              child: Container(
                decoration: VgkProGamingTheme.decoration,
                child: Padding(
                  padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
                  child: Row(
                    children: <Widget>[
                      Expanded(
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.start,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: <Widget>[
                            Text(
                              description,
                              style: VgkProGamingTheme.h4,
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        );
      },
    );
  }
}

==> vgkprogaming-0.4.5.tar.gz: lib/widget/vgk-about-us-widget/vgk-about-us-widget.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkAboutUsWidget extends StatelessWidget {
  final AnimationController animationController;
  final Animation animation;
  final String description;
  const VgkAboutUsWidget({
    Key key,
    this.animationController,
    this.animation,
    this.description,
  }) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Padding(
              padding: EdgeInsets.only(
                top: 4,
                right: VgkProGamingTheme.paddingDoubleExtraLarge,
                left: VgkProGamingTheme.paddingDoubleExtraLarge,
              ),
              child: Container(
                decoration: VgkProGamingTheme.decoration,
                child: Padding(
                  padding: VgkProGamingTheme.edgeInsetsPaddingDoubleExtraLarge,
                  child: Row(
                    children: <Widget>[
                      Expanded(
                        child: Column(
                          mainAxisAlignment: MainAxisAlignment.start,
                          crossAxisAlignment: CrossAxisAlignment.start,
                          children: <Widget>[
                            Text(
                              description,
                              style: VgkProGamingTheme.h4Black,
                            ),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ),
          ),
        );
      },
    );
  }
}
